pub(super) fn error_event_from_text(message: &str) -> ChatbotResult<Bytes>Expand description
The framed error event for a message this code raised itself, with no underlying ChatbotError.
pub(super) fn error_event_from_text(message: &str) -> ChatbotResult<Bytes>The framed error event for a message this code raised itself, with no underlying ChatbotError.